@@ -114,7 +114,8 @@ POSITIONS = {
         'NFL': get_nfl_positions(),
         'NFL_SHOWDOWN': get_nfl_showdown_positions(dk=True),
         'MLB': [
-            ['SP', 2, 2],
+            ['SP', 0, 2],
+            ['RP', 0, 2],
             ['C', 1, 1],
             ['1B', 1, 1],
             ['2B', 1, 1],
@@ -198,7 +199,9 @@ NBA_GENERAL_POSITIONS = [
     ['F', 3, 4],
     ['C', 1, 2],
 ]
-
+MLB_GENERAL_POSITIONS = [
+    ['P', 2, 2],
+]
 WNBA_GENERAL_POSITIONS = [
     ['G', 2, 3],
     ['F', 3, 4],
@@ -212,6 +215,7 @@ class RuleSet(object):
                  general_position_limits=None,
                  offensive_positions=None, defensive_positions=None,
                  max_players_per_team=None,
+                 min_teams=None,
                  game_type='classic'):
         self.site = site
         self.league = league
@@ -224,6 +228,7 @@ class RuleSet(object):
         self.defensive_positions = defensive_positions
         self.game_type = game_type
         self.max_players_per_team = max_players_per_team or (roster_size - 1)
+        self.min_teams = min_teams
 
 
 DK_NBA_RULE_SET = RuleSet(
@@ -351,7 +356,8 @@ DK_MLB_RULE_SET = RuleSet(
     roster_size=ROSTER_SIZE[DRAFT_KINGS]['MLB'],
     salary_max=SALARY_CAP[DRAFT_KINGS]['MLB'],
     position_limits=POSITIONS[DRAFT_KINGS]['MLB'],
-    general_position_limits=[],
+    general_position_limits=MLB_GENERAL_POSITIONS,
+    min_teams=3,
 )
 
 FD_MLB_RULE_SET = RuleSet(
